@@ -3,8 +3,7 @@ from .random import RandomTool
 from .context import ContextTool
 from .constant import ConstantTool
 from .param import ParamTool
-from .string.join import JoinTool
-from .string.slugify import SlugifyTool
+from .string import JoinTool, SlugifyTool
 
 tools = {
     'constant': ConstantTool(),
